@@ -29,6 +29,7 @@ from scale.utils import read_labels, cluster_report, estimate_k, binarization
 from scale.plot import plot_embedding
 
 from sklearn.preprocessing import MaxAbsScaler
+from sklearn.cluster import KMeans
 from torch.utils.data import DataLoader
 
 
@@ -40,7 +41,7 @@ if __name__ == '__main__':
     parser.add_argument('--outdir', '-o', type=str, default='output/', help='Output path')
     parser.add_argument('--verbose', action='store_true', help='Print loss of training process')
     parser.add_argument('--pretrain', type=str, default=None, help='Load the trained model')
-    parser.add_argument('--lr', type=float, default=0.002, help='Learning rate')
+    parser.add_argument('--lr', type=float, default=0.0002, help='Learning rate')
     parser.add_argument('--batch_size', '-b', type=int, default=32, help='Batch size')
     parser.add_argument('--gpu', '-g', default=0, type=int, help='Select gpu device number when training')
     parser.add_argument('--seed', type=int, default=18, help='Random seed for repeat results')
@@ -55,8 +56,8 @@ if __name__ == '__main__':
     parser.add_argument('--impute', action='store_true', help='Save the imputed data in layer impute')
     parser.add_argument('--binary', action='store_true', help='Save binary imputed data in layer binary')
     parser.add_argument('--embed', type=str, default='UMAP')
-    parser.add_argument('--reference', '-r', default=None, type=str, help='Reference celltypes')
-    parser.add_argument('--transpose', '-t', action='store_true', help='Transpose the input matrix')
+    parser.add_argument('--reference', type=str, default='celltype')
+    parser.add_argument('--cluster_method', type=str, default='leiden')
 
     args = parser.parse_args()
 
@@ -92,7 +93,7 @@ if __name__ == '__main__':
     input_dim = adata.shape[1] 	
     
     if args.n_centroids is None:
-        k = min(estimate_k(adata.X.T), 30)
+        k = estimate_k(adata.X.T)
         print('Estimate k = {}'.format(k))
     else:
         k = args.n_centroids
@@ -135,17 +136,26 @@ if __name__ == '__main__':
     # 1. latent feature
     adata.obsm['latent'] = model.encodeBatch(testloader, device=device, out='z')
 
+    # 2. cluster
     sc.pp.neighbors(adata, n_neighbors=30, use_rep='latent')
-    sc.tl.leiden(adata)
+    if args.cluster_method == 'leiden':
+        sc.tl.leiden(adata)
+    elif args.cluster_method == 'kmeans':
+        kmeans = KMeans(n_clusters=k, n_init=20, random_state=0)
+        adata.obs['kmeans'] = kmeans.fit_predict(adata.obsm['latent']).astype(str)
+
+#     if args.reference in adata.obs:
+#         cluster_report(adata.obs[args.reference].cat.codes, adata.obs[args.cluster_method].astype(int))
+
     sc.settings.figdir = outdir
     sc.set_figure_params(dpi=80, figsize=(6,6), fontsize=10)
     if args.embed == 'UMAP':
         sc.tl.umap(adata, min_dist=0.1)
-        color = [c for c in ['celltype', 'leiden'] if c in adata.obs]
+        color = [c for c in ['celltype', args.cluster_method] if c in adata.obs]
         sc.pl.umap(adata, color=color, save='.pdf', wspace=0.4, ncols=4)
     elif args.embed == 'tSNE':
-        sc.tl.tsne(adata)
-        color = [c for c in ['celltype', 'leiden'] if c in adata.obs]
+        sc.tl.tsne(adata, use_rep='latent')
+        color = [c for c in ['celltype', args.cluster_method] if c in adata.obs]
         sc.pl.tsne(adata, color=color, save='.pdf', wspace=0.4, ncols=4)
     
     if args.impute:
